@file:Suppress("EXPERIMENTAL_API_USAGE")

import ModInt.Companion.sum
import ModInt.Companion.sumOfM
import Utils.ArrayUtils.Companion.arrayOfNullsSafe
import Utils.ArrayUtils.Companion.makeDistinct
import Utils.ArrayUtils.Companion.toNotNulls
import Utils.ArrayUtils.Prints.Companion.println
import Utils.ArrayUtils.Sorts.Companion.countSort
import Utils.ArrayUtils.Sorts.Companion.shuffleSort
import Utils.ArrayUtils.Swaps.Companion.swap
import Utils.BinarySearchUtils.Companion.binarySearch
import Utils.BinarySearchUtils.Companion.binarySearchDouble
import Utils.BinarySearchUtils.Companion.binarySearchLong
import Utils.BitUtils.Companion.flip
import Utils.BitUtils.Companion.get
import Utils.BitUtils.Companion.set
import Utils.BitUtils.Companion.submaskOf
import Utils.FastReader
import Utils.GeneralUtils.Companion.catch
import Utils.GeneralUtils.Companion.length
import Utils.GeneralUtils.Companion.rnd
import Utils.MathUtils.Companion.compareDoubles
import Utils.MathUtils.Companion.gcd
import Utils.MathUtils.Companion.log2
import Utils.Pairs.Companion.ComparablePair
import Utils.Pairs.Companion.IntPair
import Utils.Points.Companion.DoublePoint
import Utils.Points.Companion.IntPoint
import Utils.Points.Companion.IntPoint.Companion.readIntPoint
import Utils.Points.Companion.LongPoint
import java.io.*
import java.util.*
import kotlin.collections.ArrayDeque
import kotlin.math.*
import kotlin.random.Random
import kotlin.random.nextInt

const val YANDEX = true
const val FORCE_LOCAL = false
val OJ = (YANDEX || System.getProperty("ONLINE_JUDGE") != null) && !FORCE_LOCAL

@Suppress("unused")
val LOCAL = !OJ

@ExperimentalStdlibApi
@ExperimentalUnsignedTypes
fun main() {
    @Suppress("UNUSED_VARIABLE", "RedundantNullableReturnType") val name: String? = null
    Locale.setDefault(Locale.US)
    val fin = if (OJ) {
//        System.setOut(PrintStream(BufferedOutputStream(FileOutputStream("$name.out"))))
//        FastReader("$name.in")
        System.setOut(PrintStream(BufferedOutputStream(System.out)))
        FastReader()
    } else {
        FastReader()
    }
    Task(fin).solve()
    System.out.flush()
}

const val eps = 1e-7

@ExperimentalStdlibApi
typealias Point = IntPoint

@ExperimentalStdlibApi
class Task(private val fin: FastReader = FastReader()) {
    fun String.toX() = indices.fold(0) { acc, i -> if (this[i] == 'W') (acc or (1 shl i)) else acc }
    fun solve() {
//        if (true) {
//            test()
//            return
//        }
        val n = fin.readInt()
        val a = IntArray(n) { fin.readString().toX() }
        for (x in solve3(a)) {
            print(x)
        }
    }

    fun test() {
        repeat(100000) {
            val n = rnd.nextInt(1..3)
            val a = IntArray(n) { rnd.nextInt(1 shl 8) }
            val r1 = solve3(a).joinToString("")
            val r2 = solveSlow(a.toList()).joinToString("")
            if (r1 != r2) {
                val results = a.map { it.toString(2).padStart(8, '0') }
                if ((0 until 8).any { results[0][it] == results[1][it] }) {
                    println(it)
                    println(n)
                    for (x in results) {
                        println(x)
                    }
                    println(r1)
                    println(r2)
                    println("---")
                }
//                return
            }
//            println(r1)
//            println(r2)
//            println(r1 == r2)
        }
    }

    fun solveSlow(a: List<Int>): List<Int> {
        return (1..a.size).map { n ->
            val dp = BooleanArray(n)
            for (i in n - 1 downTo 0) {
                dp[i] = (i + 1 until n).any { j -> !dp[j] && (j - i) <= 8 - (a[i] xor a[j]).countOneBits() }
            }
            if (dp[0]) 1 else 2
        }
    }

    fun solveFast(a: List<Int>): List<Int> {
        val n = a.size
        val dp = BooleanArray(n)
        for (i in n - 1 downTo 0) {
            dp[i] = (i + 1 until n).any { j -> !dp[j] && (j - i) <= 8 - (a[i] xor a[j]).countOneBits() }
        }
        return dp.reversed().map { if (it) 1 else 2 }
    }

    fun solve3(a: IntArray): List<Int> {
        fun isEdge(i: Int, j: Int) = (j - i) <= 8 - (a[i] xor a[j]).countOneBits()
        val n = a.size
        val dp = BooleanArray(n)
        for (i in n - 1 downTo 0) {
            dp[i] = (i + 1..min(n - 1, i + 8)).any { j -> !dp[j] && isEdge(i, j) }
        }
        fun update(v: Int): Boolean {
            val good = (v + 1..min(n - 1, v + 8)).any { j -> !dp[j] && isEdge(v, j) }
            if (good != dp[v]) {
                dp[v] = good
                return true
            } else {
                return false
            }
        }

        val ans = BooleanArray(n)
        ans[0] = dp[0]
        var at = 1
        for (i in n - 1 downTo 1) {
            dp[i] = true
            val changes = sortedSetOf(i)
            while (changes.isNotEmpty()) {
                val v = changes.pollLast()!!
                for (j in v - 1 downTo v - 10) {
                    if (j < 0 || !isEdge(i, j)) break
                    if (update(j)) changes += j
                }
            }
            ans[at++] = dp[0]
        }
        return ans.map { if (it) 1 else 2 }.reversed()
    }
}

@Suppress("MemberVisibilityCanBePrivate", "unused")
@ExperimentalStdlibApi
@ExperimentalUnsignedTypes
class Utils {
    class GeneralUtils {
        companion object {
            val rnd = Random(239)
            val IntRange.length get() = maxOf(last - first + 1, 0)

            @Suppress("UNREACHABLE_CODE", "ControlFlowWithEmptyBody")
            fun <R> catch(throwMLE: Boolean = false, f: () -> R): R {
                try {
                    return f()
                } catch (e: Exception) {
                    if (throwMLE) throw OutOfMemoryError()
                    while (true) {
                    }
                    throw e
                }
            }
        }
    }

    class MathUtils {
        companion object {
            tailrec fun gcd(a: Int, b: Int): Int = if (b == 0) a else gcd(b, a % b)
            tailrec fun gcd(a: Long, b: Long): Long = if (b == 0L) a else gcd(b, a % b)

            fun Int.log2(): Int {
                var log = 0
                while (1 shl log < this) log++
                return log
            }

            fun Long.log2(): Int {
                var log = 0
                while (1L shl log < this) log++
                return log
            }

            fun compareDoubles(x: Double, y: Double) = if (abs(x - y) < eps) 0 else if (x < y) -1 else +1
            fun isZero(x: Double) = abs(x) < eps
        }
    }

    class BitUtils {
        companion object {
            operator fun Int.get(bit: Int) = (this shr bit) and 1
            operator fun Long.get(bit: Int) = ((this shr bit) and 1).toInt()
            fun Int.set(bit: Int) = this or (1 shl bit)
            fun Long.set(bit: Int) = this or (1L shl bit)
            fun Int.flip(bit: Int) = this xor (1 shl bit)
            fun Long.flip(bit: Int) = this xor (1L shl bit)
            infix fun Int.submaskOf(x: Int) = (this and x) == this
            infix fun Long.submaskOf(x: Long) = (this and x) == this
        }
    }

    class ArrayUtils {
        companion object {
            fun <T : Comparable<T>> MutableList<T>.makeDistinct() {
                if (size <= 1) return
                sort()
                var sz = 1
                for (i in 1 until size) {
                    if (this[i] != this[i - 1]) {
                        this[sz++] = this[i]
                    }
                }
                while (size > sz) removeAt(lastIndex)
            }

            @Suppress("UNCHECKED_CAST")
            fun <T> Array<T?>.toNotNulls() = this as Array<T>

            @Suppress("UNCHECKED_CAST")
            inline fun <reified T> arrayOfNullsSafe(size: Int): Array<T> = arrayOfNulls<T>(size).toNotNulls()
        }

        class Swaps {
            companion object {
                fun <T> Array<T>.swap(i: Int, j: Int) {
                    val x = this[i]
                    this[i] = this[j]
                    this[j] = x
                }

                fun <T> MutableList<T>.swap(i: Int, j: Int) {
                    val x = this[i]
                    this[i] = this[j]
                    this[j] = x
                }

                fun IntArray.swap(i: Int, j: Int) {
                    val x = this[i]
                    this[i] = this[j]
                    this[j] = x
                }

                fun LongArray.swap(i: Int, j: Int) {
                    val x = this[i]
                    this[i] = this[j]
                    this[j] = x
                }

                fun DoubleArray.swap(i: Int, j: Int) {
                    val x = this[i]
                    this[i] = this[j]
                    this[j] = x
                    sort()
                }

                fun CharArray.swap(i: Int, j: Int) {
                    val x = this[i]
                    this[i] = this[j]
                    this[j] = x
                    sort()
                }
            }
        }

        class Sorts {
            companion object {
                fun IntArray.shuffleSort() {
                    for (i in 1 until size) swap(i, rnd.nextInt(i + 1))
                    sort()
                }

                fun LongArray.shuffleSort() {
                    for (i in 1 until size) swap(i, rnd.nextInt(i + 1))
                    sort()
                }

                fun DoubleArray.shuffleSort() {
                    for (i in 1 until size) swap(i, rnd.nextInt(i + 1))
                    sort()
                }

                fun CharArray.shuffleSort() {
                    for (i in 1 until size) swap(i, rnd.nextInt(i + 1))
                    sort()
                }

                inline fun <reified T> Array<T>.countSort(inPlace: Boolean = true, type: (T) -> Int): Array<T> {
                    val types = IntArray(size) { type(this[it]) }
                    val min = types.minOrNull()!!
                    val max = types.maxOrNull()!!
                    val count = IntArray(max - min + 1)
                    for (t in types) count[t - min]++
                    var sum = 0
                    for (i in count.indices) {
                        val shift = count[i]
                        count[i] = sum
                        sum += shift
                    }
                    val sorted = arrayOfNullsSafe<T>(size)
                    for (i in 0 until size) sorted[count[types[i] - min]++] = this[i]
                    return if (inPlace) {
                        sorted.copyInto(this)
                        this
                    } else {
                        sorted
                    }
                }
            }
        }

        class Prints {
            companion object {
                fun println(a: IntArray) {
                    if (a.isNotEmpty()) {
                        print(a[0])
                        for (i in 1 until a.size) {
                            print(' ')
                            print(a[i])
                        }
                    }
                    println()
                }

                fun println(a: LongArray) {
                    if (a.isNotEmpty()) {
                        print(a[0])
                        for (i in 1 until a.size) {
                            print(' ')
                            print(a[i])
                        }
                    }
                    println()
                }

                fun println(a: CharArray, printSpace: Boolean = false) {
                    if (a.isNotEmpty()) {
                        print(a[0])
                        for (i in 1 until a.size) {
                            if (printSpace) print(' ')
                            print(a[i])
                        }
                    }
                    println()
                }

                fun println(a: Array<*>) {
                    if (a.isNotEmpty()) {
                        print(a[0])
                        for (i in 1 until a.size) {
                            print(' ')
                            print(a[i])
                        }
                    }
                    println()
                }

                fun println(a: List<*>) {
                    if (a.isNotEmpty()) {
                        print(a[0])
                        for (i in 1 until a.size) {
                            print(' ')
                            print(a[i])
                        }
                    }
                    println()
                }

                fun println(a: Iterable<*>) {
                    val it = a.iterator()
                    if (it.hasNext()) {
                        print(it.next())
                        while (it.hasNext()) {
                            print(' ')
                            print(it.next())
                        }
                    }
                    println()
                }
            }
        }
    }

    class BinarySearchUtils {
        companion object {
            @Suppress("DuplicatedCode")
            inline fun binarySearch(from: Int, to: Int, f: (Int) -> Boolean): Int {
                var l = from
                var r = to + 1
                while (r - l > 1) {
                    val m = (l + r) / 2
                    if (f(m)) l = m
                    else r = m
                }
                return l
            }

            inline fun binarySearch(from: Int = 0, f: (Int) -> Boolean): Int {
                var len = 1
                while (f(from + len)) len *= 2
                return binarySearch(from + len / 2, from + len - 1, f)
            }

            @Suppress("DuplicatedCode")
            inline fun binarySearchLong(from: Long, to: Long, f: (Long) -> Boolean): Long {
                var l = from
                var r = to + 1
                while (r - l > 1) {
                    val m = (l + r) / 2
                    if (f(m)) l = m
                    else r = m
                }
                return l
            }

            inline fun binarySearchLong(from: Long = 0, f: (Long) -> Boolean): Long {
                var len = 1L
                while (f(from + len)) len *= 2
                return binarySearchLong(from + len / 2, from + len - 1, f)
            }

            @Suppress("DuplicatedCode")
            inline fun binarySearchDouble(from: Double, to: Double, times: Int = 200, f: (Double) -> Boolean): Double {
                var l = from
                var r = to
                repeat(times) {
                    val m = (l + r) / 2
                    if (f(m)) l = m
                    else r = m
                }
                return l
            }

            inline fun binarySearchDouble(from: Double = 0.0, times: Int = 200, f: (Double) -> Boolean): Double {
                var len = 1.0
                while (f(from + len)) len *= 2
                return binarySearchDouble(from, from + len, times, f)
            }
        }
    }

    class Pairs {
        companion object {
            data class ComparablePair<T1 : Comparable<T1>, T2>(val first: T1, val second: T2) :
                Comparable<ComparablePair<T1, T2>> {
                override fun compareTo(other: ComparablePair<T1, T2>) = first.compareTo(other.first)
            }

            data class IntPair(val first: Int, val second: Int) : Comparable<IntPair> {
                override fun compareTo(other: IntPair): Int {
                    var c = first.compareTo(other.first)
                    if (c == 0) c = second.compareTo(other.second)
                    return c
                }
            }
        }
    }

    class Points {
        companion object {
            data class IntPoint(val x: Int, val y: Int) : Comparable<IntPoint> {
                operator fun plus(p: IntPoint) = IntPoint(x + p.x, y + p.y)
                operator fun minus(p: IntPoint) = IntPoint(x - p.x, y - p.y)
                operator fun times(k: Int) = IntPoint(x * k, y * k)
                operator fun times(p: IntPoint) = x * p.y - y * p.x
                operator fun rem(p: IntPoint) = x * p.x + y * p.y
                operator fun unaryMinus() = IntPoint(-x, -y)
                override fun toString() = "$x $y"

                fun len2() = x * x + y * y
                fun len() = hypot(x.toDouble(), y.toDouble())
                fun angle() = atan2(y.toDouble(), x.toDouble())
                fun vecSign(p: IntPoint) = (x * p.y).compareTo(y * p.x)
                fun vector() = if (this == ORIGIN) this else gcd(abs(x), abs(y)).let { IntPoint(x / it, y / it) }

                override fun compareTo(other: IntPoint): Int {
                    var c = x.compareTo(other.x)
                    if (c == 0) c = y.compareTo(other.y)
                    return c
                }

                companion object {
                    val ORIGIN = IntPoint(0, 0)
                    fun FastReader.readIntPoint() = IntPoint(readInt(), readInt())
                }
            }

            data class LongPoint(val x: Long, val y: Long) : Comparable<LongPoint> {
                operator fun plus(p: LongPoint) = LongPoint(x + p.x, y + p.y)
                operator fun minus(p: LongPoint) = LongPoint(x - p.x, y - p.y)
                operator fun times(k: Long) = LongPoint(x * k, y * k)
                operator fun times(p: LongPoint) = x * p.y - y * p.x
                operator fun rem(p: LongPoint) = x * p.x + y * p.y
                operator fun unaryMinus() = LongPoint(-x, -y)
                override fun toString() = "$x $y"

                fun len2() = x * x + y * y
                fun len() = hypot(x.toDouble(), y.toDouble())
                fun angle() = atan2(y.toDouble(), x.toDouble())
                fun vecSign(p: LongPoint) = (x * p.y).compareTo(y * p.x)
                fun vector() = if (this == ORIGIN) this else gcd(abs(x), abs(y)).let { LongPoint(x / it, y / it) }

                override fun compareTo(other: LongPoint): Int {
                    var c = x.compareTo(other.x)
                    if (c == 0) c = y.compareTo(other.y)
                    return c
                }

                companion object {
                    val ORIGIN = LongPoint(0, 0)
                    fun FastReader.readLongPoint() = LongPoint(readLong(), readLong())
                }
            }

            data class DoublePoint(val x: Double, val y: Double) : Comparable<DoublePoint> {
                operator fun plus(p: DoublePoint) = DoublePoint(x + p.x, y + p.y)
                operator fun minus(p: DoublePoint) = DoublePoint(x - p.x, y - p.y)
                operator fun times(k: Double) = DoublePoint(x * k, y * k)
                operator fun times(p: DoublePoint) = x * p.y - y * p.x
                operator fun rem(p: DoublePoint) = x * p.x + y * p.y
                operator fun unaryMinus() = DoublePoint(-x, -y)
                override fun toString() = "%.20f %.20f".format(x, y)

                fun len2() = x * x + y * y
                fun len() = hypot(x, y)
                fun angle() = atan2(y, x)
                fun vecSign(p: DoublePoint) = compareDoubles(x * p.y, y * p.x)
                fun vector() = if (this == ORIGIN) this else len().let { DoublePoint(x / it, y / it) }

                override fun compareTo(other: DoublePoint): Int {
                    var c = compareDoubles(x, other.x)
                    if (c == 0) c = compareDoubles(y, other.y)
                    return c
                }

                override fun equals(other: Any?) = other is DoublePoint && compareTo(other) == 0
                override fun hashCode() = 0

                companion object {
                    val ORIGIN = DoublePoint(0.0, 0.0)
                    fun FastReader.readDoublePoint() = DoublePoint(readDouble(), readDouble())
                }
            }
        }
    }

    class UtilsImports {
        fun importDependencies() {
            check(gcd(4, 6) == 2)
            check(rnd.nextInt(10) in 0 until 10)
            check(mutableListOf(1, 3, 2, 2, 1).apply { makeDistinct() } == listOf(1, 2, 3))
            check((5..10).length == 6)
            check(intArrayOf(3, 4).apply { swap(0, 1) }.contentEquals(intArrayOf(4, 3)))
            check(intArrayOf(5, 6, 2, 1, 5).apply { shuffleSort() }.contentEquals(intArrayOf(1, 2, 5, 5, 6)))
            check(binarySearch { it < 10 } == 9)
            check(binarySearchLong { it < 1e13.toLong() } == 1e13.toLong() - 1)
            binarySearchDouble { true }
            println(intArrayOf())
            ArrayDeque<Int>()
            listOf<ModInt>().sumOfM { it }
            listOf<ModInt>().sum()
            abs(1)
            sin(1.0)
            cos(1.0)
            hypot(1.0, 1.0)
            catch {}
            ComparablePair(1, 2)
            IntPair(1, 2)
            IntPoint(0, 0)
            arrayOfNulls<Int>(0).toNotNulls()
            arrayOfNullsSafe<Int>(0)
            FastReader().readIntPoint()
            5.log2()
            @Suppress("ReplaceGetOrSet")
            5.get(3)
            5.sign
            5 submaskOf 3
            5.set(3)
            5.flip(3)
            compareDoubles(0.0, 1.0)
            IntPoint(1, 1)
            LongPoint(1, 1)
            DoublePoint(0.0, 0.0)
            arrayOf(1, 2).countSort { it.countOneBits() }
        }
    }

    class FastReader(fileName: String? = null) {
        @JvmField
        val br = BufferedReader(if (fileName != null) FileReader(fileName) else InputStreamReader(System.`in`))

        @JvmField
        var st = StringTokenizer("")

        fun readString(): String {
            while (!st.hasMoreTokens()) st = StringTokenizer(br.readLine())
            return st.nextToken()
        }

        fun readInt() = readString().toInt()
        fun readLong() = readString().toLong()
        fun readDouble() = readString().toDouble()

        fun readIntArray(n: Int) = IntArray(n) { readInt() }
        fun readLongArray(n: Int) = LongArray(n) { readLong() }
        fun readStringArray(n: Int) = Array(n) { readString() }
        fun readDoubleArray(n: Int) = DoubleArray(n) { readDouble() }

        fun readInts(n: Int) = MutableList(n) { readInt() }
        fun readLongs(n: Int) = MutableList(n) { readLong() }
        fun readStrings(n: Int) = MutableList(n) { readString() }
        fun readDoubles(n: Int) = MutableList(n) { readDouble() }
    }
}

@Suppress("MemberVisibilityCanBePrivate", "unused")
@ExperimentalStdlibApi
@ExperimentalUnsignedTypes
inline class ModInt(private val x: Int) {
    companion object {
//        private const val mod = 998_244_353

        const val mod = 1e9.toInt() + 7
        fun Int.toModInt() = ModInt(this)
        fun Int.toModIntSafe() = ModInt((this % mod + mod) % mod)
        fun Long.toModIntSafe() = ModInt(((this % mod + mod) % mod).toInt())
        val ZERO = ModInt(0)
        val ONE = ModInt(1)
        val TWO = ModInt(2)
        val TEN = ModInt(10)

        fun Iterable<ModInt>.sum() = fold(ZERO, ModInt::plus)
        fun Array<ModInt>.sum() = fold(ZERO, ModInt::plus)

        inline fun <T> Iterable<T>.sumOfM(f: (T) -> ModInt) = fold(ZERO) { acc, i -> acc + f(i) }
        inline fun <T> Array<T>.sumOfM(f: (T) -> ModInt) = fold(ZERO) { acc, i -> acc + f(i) }
    }

    operator fun plus(k: ModInt) = ModInt((x + k.x).let { if (it >= mod) it - mod else it })
    operator fun minus(k: ModInt) = ModInt((x - k.x).let { if (it < 0) it + mod else it })
    operator fun times(k: ModInt) = ModInt((x * k.x.toLong() % mod).toInt())
    operator fun div(k: ModInt) = this * k.inv()
    operator fun unaryMinus() = if (x == 0) this else ModInt(mod - x)
    fun inv() = pow(mod - 2)
    fun pow(p: Int): ModInt = if (p == 0) ONE else pow(p / 2).let { if (p % 2 == 1) it * it * this else it * it }
    fun toInt() = x
    override fun toString() = x.toString()
}