// #pragma comment(linker, "/stack:200000000")
// #pragma GCC optimize("Ofast,no-stack-protector")
// #pragma GCC target("sse,sse2,sse3,ssse3,sse4,popcnt,abm,mmx,avx,avx2,tune=native")
// #pragma GCC optimize("unroll-loops")

#include <bits/stdc++.h>

#ifdef PERVEEVM_LOCAL
    #define debug(x) std::cerr << (#x) << ":\t" << (x) << std::endl
#else
    #define debug(x) 238;
#endif

#define fastIO std::ios_base::sync_with_stdio(false); std::cin.tie(0); std::cout.tie(0)
#define NAME "File"

using ll = long long;
using ld = long double;

#ifdef PERVEEVM_LOCAL
    std::mt19937 rnd(238);
#else
    std::mt19937 rnd(std::chrono::high_resolution_clock::now().time_since_epoch().count());
#endif

const double PI = atan2(0.0, -1.0);
const int INF = 0x3f3f3f3f;
const ll LINF = (ll)2e18;
const int N = 200100;

class Query {
public:
    int l, r, id;

    Query() = default;

    Query(int l, int r, int id) : l(l), r(r), id(id) {}

    bool operator<(const Query& other) {
        return r < other.r;
    }
};

Query allQ[N];
std::vector<int> trans;
int left[N], right[N], key[N], min[N], max[N];
int badCnt[N];

void dfs(int v) {
    min[v] = key[v];
    max[v] = key[v];

    if (left[v] != -1) {
        dfs(left[v]);
        min[v] = std::min(min[v], min[left[v]]);
        max[v] = std::max(max[v], max[left[v]]);
    }
    if (right[v] != -1) {
        dfs(right[v]);
        min[v] = std::min(min[v], min[right[v]]);
        max[v] = std::max(max[v], max[right[v]]);
    }
}

int makeTrans(int x) {
    return std::lower_bound(trans.begin(), trans.end(), x) - trans.begin();
}

int prefSum[3 * N];

int get(int pos) {
    ++pos;

    if (pos <= 0) {
        return 0;
    }

    int ans = 0;
    for (; pos > 0; pos -= pos & -pos) {
        ans += prefSum[pos];
    }
    return ans;
}

void add(int pos, int delta) {
    ++pos;

    for (; pos < 3 * N; pos += pos & -pos) {
        prefSum[pos] += delta;
    }
}

void run() {
    int n;
    scanf("%d", &n);

    for (int i = 0; i < n; ++i) {
        scanf("%d%d%d", &left[i], &right[i], &key[i]);
        --left[i];
        --right[i];
        trans.push_back(key[i]);
    }    

    int q;
    scanf("%d", &q);

    for (int i = 0; i < q; ++i) {
        scanf("%d%d", &allQ[i].l, &allQ[i].r);
        allQ[i].id = i;
        trans.push_back(allQ[i].l);
        trans.push_back(allQ[i].r);
    }

    std::sort(trans.begin(), trans.end());
    trans.resize(std::unique(trans.begin(), trans.end()) - trans.begin());

    for (int i = 0; i < n; ++i) {
        key[i] = makeTrans(key[i]);
        // debug(key[i]);
    }
    for (int i = 0; i < q; ++i) {
        allQ[i].l = makeTrans(allQ[i].l);
        allQ[i].r = makeTrans(allQ[i].r);
    }

    dfs(0);

    std::vector<std::pair<int, int>> vertexes(n);
    for (int i = 0; i < n; ++i) {
        vertexes[i] = std::make_pair(min[i], max[i]);
    }

    // for (auto& [l, r] : vertexes) {
    //     std::cout << l << ' ' << r << std::endl;
    // }

    for (auto& [l, r] : vertexes) {
        ++prefSum[r];
    }
    for (int i = 1; i < 3 * N; ++i) {
        prefSum[i] += prefSum[i - 1];
    }
    for (int i = 0; i < q; ++i) {
        if (allQ[i].l != 0) {
            badCnt[allQ[i].id] += prefSum[allQ[i].l - 1];
        }
    }

    memset(prefSum, 0, sizeof(prefSum));

    for (auto& [l, r] : vertexes) {
        ++prefSum[l];
    }
    for (int i = 3 * N - 2; i >= 0; --i) {
        prefSum[i] += prefSum[i + 1];
    }
    for (int i = 0; i < q; ++i) {
        if (allQ[i].r != 3 * N - 1) {
            badCnt[allQ[i].id] += prefSum[allQ[i].r + 1];
        }
    }

    memset(prefSum, 0, sizeof(prefSum));

    std::sort(allQ, allQ + q);
    std::sort(vertexes.begin(), vertexes.end(), [&](std::pair<int, int> p1, std::pair<int, int> p2) {
        return p1.second < p2.second;
    });

    int ptr = 0;
    int added = 0;

    // std::cout << allQ[q - 1].l << ' ' << allQ[q - 1].r << std::endl;

    for (int i = 0; i < q; ++i) {
        while (ptr < (int)vertexes.size() && vertexes[ptr].second <= allQ[i].r) {
            ++added;
            add(vertexes[ptr].first, 1);
            ++ptr;
        }

        badCnt[allQ[i].id] += added - get(allQ[i].l - 1);
        // std::cout << added << ' ' << get(allQ[i].l) << ' ' << allQ[i].l << std::endl;
    }

    // for (int i = 0; i < q; ++i) {
    //     std::cout << badCnt[i] << ' ';
    // }
    // std::cout << std::endl;

    for (int i = 0; i < q; ++i) {
        printf("%d\n", 1 + 2 * (n - badCnt[i]));
    }
}

int main(void) {
    // freopen(NAME".in", "r", stdin);
    // freopen(NAME".out", "w", stdout);

    auto start = std::chrono::high_resolution_clock::now();
    run();
    auto end = std::chrono::high_resolution_clock::now();

    #ifdef PERVEEVM_LOCAL
        std::cerr << "Execution time: "
                  << std::chrono::duration_cast<std::chrono::milliseconds>(end - start).count()
                  << " ms" << std::endl;
    #endif

    return 0;
}
