#pragma GCC optimize("O3")
#pragma GCC optimize("unroll-loops")

#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ld = long double;
using pii = pair<int, int>;
using cd = complex<ld>;

struct pt {
  ll x, y;

  pt() : x(0), y(0) {}

  pt(ll x, ll y) : x(x), y(y) {}
};

pt operator+(const pt &a, const pt &b) {
  return pt(a.x + b.x, a.y + b.y);
}

pt operator-(const pt &a, const pt &b) {
  return pt(a.x - b.x, a.y - b.y);
}

bool operator<(const pt &a, const pt &b) {
  return tie(a.x, a.y) < tie(b.x, b.y);
}

ll cross(pt const &a, pt const &b) {
  return a.x * b.y - a.y * b.x;
}

istream &operator>>(istream &in, pt &p) {
  in >> p.x >> p.y;
  return in;
}

ostream &operator<<(ostream &out, pt const &p) {
  out << "(" << p.x << ", " << p.y << ")";
  return out;
}

bool operator==(const pt &a, const pt &b) {
  return a.x == b.x && a.y == b.y;
}

const ld EPS = 1e-8;

struct line {
  ll a, b, c;

  line(ld a, ld b, ld c) : a(a), b(b), c(c) {}

  line(const pt &p, const pt &q) {
    a = q.y - p.y;
    b = p.x - q.x;
    c = -(a * p.x + b * p.y);

    ll g = __gcd(abs(a), abs(b));
    a /= g;
    b /= g;
    c /= g;

    if (a < 0) {
      a = -a;
      b = -b;
      c = -c;
    } else if (a == 0 && b < 0) {
      a = -a;
      b = -b;
      c = -c;
    }
  }

  ll calc(pt p) const {
    return a * p.x + b * p.y + c;
  }
};

bool operator==(const line &a, const line &b) {
  return a.a == b.a && a.b == b.b && a.c == b.c;
}

bool haveIntersection(const line &a, const line &b) {
  return abs(a.a * b.b - a.b * b.a) > 0;
}

pt intersect(const line &a, const line &b) {
  ld det = a.a * b.b - a.b * b.a;
  return pt(roundl((0.0l - a.c * b.b + a.b * b.c) / det), roundl((-a.a * b.c + a.c * b.a + 0.0l) / det));
}

template<int MOD>
struct modInt {
  int x;

  void normalize() {
    if (x < 0) x += MOD;
    else if (x >= MOD) x -= MOD;
  }

  modInt() = default;

  modInt(int x) : x(x) {
    normalize();
  }

  modInt(ll x) : x(x % MOD) {
    normalize();
  }

  friend modInt operator+(const modInt &a, const modInt &b) {
    return modInt(a.x + b.x);
  }

  friend modInt operator-(const modInt &a, const modInt &b) {
    return modInt(a.x - b.x);
  }

  friend modInt operator*(const modInt &a, const modInt &b) {
    return modInt((ll) a.x * b.x);
  }

  friend modInt operator/(modInt a, modInt b) {
    int p = MOD - 2;
    while (p > 0) {
      if (p & 1) {
        a = a * b;
      }
      b = b * b;
      p >>= 1;
    }
    return a;
  }

  modInt &operator+=(const modInt &b) {
    return *this = *this + b;
  }

  modInt &operator-=(const modInt &b) {
    return *this = *this - b;
  }

  modInt &operator*=(const modInt &b) {
    return *this = *this * b;
  }

  modInt &operator/=(const modInt &b) {
    return *this = *this / b;
  }
};

template<int MOD>
ostream &operator<<(ostream &out, modInt<MOD> const &x) {
  out << x.x;
  return out;
}

using mint = modInt<1'000'000'007>;

const int N = 2'000'000;

mint fact[N];
mint invFact[N];

ll square(const vector<pt> &pts) {
  return cross(pts[1] - pts[0], pts[2] - pts[0]);
}

bool inside(vector<pt> const &a, pt const &p, ll s) {
  for (int i = 0; i < 3; i++) {
    s -= abs(cross(a[i] - p, a[(i + 1) % 3] - p));
  }
  return s == 0;
}

mint C(int n, int k) {
  return n < k ? 0 : fact[n] * invFact[k] * invFact[n - k];
}

mint sum(ll l, ll r, int k) {
  if (r < 0) {
    return 0;
  } else if (l > 1'000'000) {
    return 0;
  }
  l = max(0ll, l);
  r = max(0ll, r);
  return C(r + 1, k + 1) - C(l, k + 1);
}

pt p1, p2, p3;

void read() {
  cin >> p1 >> p2 >> p3;
}

const int RANGE = 2;

mint slow_solve() {
  return 0;
}

mt19937 rnd(873654);

int next(int l, int r) {
  return l + rnd() % (r - l + 1);
}

void gen() {
  while (true) {
    p1 = {next(-RANGE, RANGE), next(-RANGE, RANGE)};
    p2 = {next(-RANGE, RANGE), next(-RANGE, RANGE)};
    p3 = {next(-RANGE, RANGE), next(-RANGE, RANGE)};
    if (abs(cross(p2 - p1, p3 - p1)) == 0) {
      continue;
    }
    break;
  }
}

pair<ll, ll> intersect(vector<pt> const &a, line const &l, int k) {
  ll minY = 1e18, maxY = -1e18;
  ll s =square(a);
  for (int i = 0; i < 3; i++) {
    line edge(a[i], a[(i + 1) % 3]);
    if (haveIntersection(edge, l)) {
      pt p = intersect(edge, l);
      for (int dx = -1; dx <= 1; dx++) {
        p.x += dx;
        p.y = -l.calc(pt(p.x, 0));
//        assert(l.calc(p) == 0);
        if (inside(a, p,s) && l.calc(p) == 0) {
          minY = min(minY, p.y);
          maxY = max(maxY, p.y);
        }
        p.x -= dx;
      }
    }
  }
  return {minY, maxY};
}

int fullIntersection(vector<pt> const &a, line const &l) {
  for (int i = 0; i < 3; i++) {
    line edge(a[i], a[(i + 1) % 3]);
    if (edge == l) {
      return i;
    }
  }
  return -1;
}

mint solve() {
  vector<pt> triangle = {p1, p2, p3};

  mint res = 0;
  const int ITER = 1'000'000 + 1;
  for (int i = 0; i <= ITER; i++) {
    line l(pt(i, i), pt(i - 1, i + 1));
    int full = fullIntersection(triangle, l);
    if (full != -1) {
      ll l = (ll) triangle[full].y;
      ll r = (ll) triangle[(full + 1) % 3].y;
      if (l > r) {
        swap(l, r);
      }
      res += sum(l, r, i);
      continue;
    }

    auto[minY, maxY] = intersect(triangle, l, i);
    if (minY == 1e18) {
      continue;
    }
    res += sum(minY, maxY, i);
  }
  return res;
}

void precalc() {
  fact[0] = fact[1] = 1;
  for (int i = 2; i < N; i++) {
    fact[i] = fact[i - 1] * i;
  }
  invFact[N - 1] = 1 / fact[N - 1];
  for (int i = N - 2; i >= 0; i--) {
    invFact[i] = invFact[i + 1] * (i + 1);
  }
}

void stress() {
  while (true) {
    gen();
    auto jans = slow_solve();
    auto pans = solve();
    if (jans.x != pans.x) {
      cout << "polygon([";
      cout << p1 << "," << p2 << "," << p3 << "])" << endl;
      cout << "Expected: " << jans << endl;
      cout << "Found: " << pans << endl;
      cout << "1\n";
      cout << p1.x << " " << p1.y << " " << p2.x << " " << p2.y << " " << p3.x << " " << p3.y << endl;
      exit(0);
    }
    cout << "YES" << endl;
  }
}

int main() {
  ios_base::sync_with_stdio(false);
  cin.tie(nullptr);

  precalc();
//  stress();

  int test;
  cin >> test;
  while (test--) {
    read();
    cout << solve() << "\n";
  }

  return 0;
}