
#pragma GCC optimize("O3")
#pragma GCC target("sse,sse2,sse3,ssse3,sse4,popcnt,abm,mmx")
#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ld = long double;

const int mod = 1e9 + 7;

ll binpow(ll a, ll p) {
    ll res = 1;
    while (p) {
        if (p & 1) {
            (res *= a) %= mod;
        }
        p >>= 1;
        (a *= a) %= mod;
    }
    return res;
}

const int N = 1e6 + 5;

ll f[N], fr[N];

ll cnk(int n, int k) {
    if (k < 0 || k > n) return 0;
    return f[n] * fr[k] % mod * fr[n - k] % mod;
}

class Point {
public:
    ll x, y;
public:
    Point(): x(0), y(0){}
    Point(ll x, ll y): x(x), y(y) {}
    ll len2() const {
        return x * x + y * y;
    }

    ld len() const {
        return sqrt(len2());
    }

    ll sc_prod(Point other) const {
        return x * other.x + y * other.y;
    }

    ll vec_prod(Point other) const {
        return x * other.y - y * other.x;
    }

    Point operator -(const Point& other) const {
        return Point(x - other.x, y - other.y);
    }
};

bool in_rect(Point pnt, Point a, Point b) {
    return pnt.vec_prod(b - a) == 0 && pnt.x <= max(a.x, b.x) && pnt.x >= min(a.x, b.x) &&
    pnt.y <= max(a.y, b.y) && pnt.y >= min(a.x, b.x);
}

bool in_triangle(Point pnt, Point a, Point b) {
    Point c = b - a;
    if (pnt.x <= max(0ll, max(b.x, a.x)) && pnt.x >= min(0ll, min(b.x, a.x)) &&
        pnt.y <= max(0ll, max(b.y, a.y)) && pnt.y >= min(0ll, min(b.y, a.y))) {
        if (in_rect(pnt, Point(0, 0), a)||
            in_rect(pnt, a, b) ||
            in_rect(pnt, Point(0, 0), b)) {
            return true;
        } else {
            if (((pnt.vec_prod(a) < 0) == ((pnt - a).vec_prod(c) < 0)) &&
                ((pnt - a).vec_prod(c) < 0) == ((pnt - b).vec_prod(Point(0, 0) - b) < 0)) {
                return true;
            }
        }
    }
    return false;
}

struct Line {
    ld a, b, c;
};

const ld EPS = 1e-11;

ld det(ld a, ld b, ld c, ld d) {
    return a*d - b*c;
}

bool intersect(Line m, Line n, pair<ld, ld>& res) {
    ld zn = det(m.a, m.b, n.a, n.b);
    if (abs(zn) < EPS)
        return false;
    res.first = -det(m.c, m.b, n.c, n.b) / zn;
    res.second = -det(m.a, m.c, n.a, n.c) / zn;
    return true;
}

bool parallel(Line m, Line n) {
    return abs(det(m.a, m.b, n.a, n.b)) < EPS;
}

bool equivalent(Line m, Line n) {
    return abs(det(m.a, m.b, n.a, n.b)) < EPS
        && abs(det(m.a, m.c, n.a, n.c)) < EPS
        && abs(det(m.b, m.c, n.b, n.c)) < EPS;
}

void solve() {
    vector<Point> pnt(3);
    vector<Line> line(3);
    for (int i = 0; i < 3; i++) {
        cin >> pnt[i].x >> pnt[i].y;
    }
    for (int i = 0; i < 3; i++) {
        int j = (i + 1) % 3;
        line[i].a = pnt[j].y - pnt[i].y;
        line[i].b = pnt[i].x - pnt[j].x;
        line[i].c = -line[i].a * pnt[i].x - line[i].b * pnt[i].y;
    }
    
    ll ans = 0;
    ll cur = 1;
    ll cl = 0;
    ll cr = 0;
    vector<ld> inter;
    for (ll n = 0; n < N; n++) {
        inter.clear();
        Line hor;
        hor.a = 0;
        hor.b = 1;
        hor.c = -n;
        for (int j = 0; j < 3; j++) {
            if (equivalent(line[j], hor)) {
                inter.push_back(pnt[j].x);
                inter.push_back(pnt[(j + 1) % 3].x);
            } else {
                pair<ld, ld> res;
                if (intersect(line[j], hor, res)) {
                    inter.push_back(res.first);
                }
            }
        }
        int l = 1e9, r = -1e9;
        Point p;
        p.y = n;
        Point A = pnt[1] - pnt[0];
        Point B = pnt[2] - pnt[0];
        for (int j = 0; j < inter.size(); j++) {
            inter[j] = max<ld>(inter[j], -n);
            inter[j] = min<ld>(inter[j], n);
            for (p.x = max<ll>(inter[j] - 6, -n); p.x <= min<ll>(inter[j] + 6, n); p.x++) {
                if (in_triangle(p - pnt[0], A, B)) {
                    l = min<int>(l, p.x); 
                    r = max<int>(r, p.x);
                }
            }
        }
        
        if (l < 1e9) {
            if ((l % 2 + 2) % 2 != n % 2) {
                l++;
            }
            if ((r % 2 + 2) % 2 != n % 2) {
                r--;
            }
        }
        if (l < 1e9 && l <= r) {
            while (cr < r) {
                cur = (cur + cnk(n, (cr + n) / 2 + 1)) % mod;
                cr += 2;
            }
            while (cl > l) {
                cur = (cur + cnk(n, (cl + n) / 2 - 1)) % mod;
                cl -= 2;
            }
            while (cl < l) {
                cur = (cur - cnk(n, (cl + n) / 2) + mod) % mod;
                cl += 2;
            }
            while (cr > r) {
                cur = (cur - cnk(n, (cr + n) / 2) + mod) % mod;
                cr -= 2;
            }
            ans = (ans + cur) % mod;
        }
        
        cur = cur * 2 % mod;
        cur = (cur + cnk(n, (cl + n) / 2 - 1) + cnk(n, (cr + n) / 2 + 1)) % mod;
        cl--;
        cr++;
    }
    cout << ans << '\n';
}

int32_t main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    f[0] = fr[0] = 1;
    for (int i = 1; i < N; i++) {
        f[i] = f[i - 1] * i % mod;
        fr[i] = binpow(f[i], mod - 2);
    }
    
    int T = 1;
    cin >> T;
    for (int tc = 1; tc <= T; tc++) {
        // cout << "Case " << tc << ": ";
        solve();
    }
    return 0;
}