#pragma comment(linker, "/STACK:2000000000")
# include <iostream>
# include <cmath>
# include <algorithm>
# include <stdio.h>
# include <cstdint>
# include <cstring>
# include <string>
# include <cstdlib>
# include <vector>
# include <bitset>
# include <map>
# include <queue>
# include <ctime>
# include <stack>
# include <set>
# include <list>
# include <random>
# include <deque>
# include <functional>
# include <iomanip>
# include <sstream>
# include <fstream>
# include <complex>
# include <numeric>
# include <immintrin.h>
# include <cassert>
# include <array>
# include <tuple>
# include <unordered_map>
# include <unordered_set>
# include <thread>

using namespace std;

using ll = long long;
using ull = unsigned long long;
using ld = long double;
using ui32 = unsigned int;
constexpr ll INFLL = 1e18;

#define CHECK_IMPL1(cond)              \
if (!(cond)) {                         \
    DEBUG("expected cond: " << #cond); \
    assert(cond);                      \
}

#define CHECK_IMPL2(cond, message)                                            \
if (!(cond)) {                                                                \
    DEBUG("expected cond: " << #cond << " failed with message: " << message); \
    assert(cond);                                                             \
}
#define CHECK_IMPL(_1, _2, NAME, ...) NAME
#define CHECK(...) CHECK_IMPL(__VA_ARGS__, CHECK_IMPL2, CHECK_IMPL1, CHECK_IMPL0)(__VA_ARGS__)

#ifdef __APPLE__
#define DEBUG(message) //std::cerr << message << std::endl;
#else
#define DEBUG(message)
#endif

const int MAXN = 1000 * 1000;

class Trie {
public:
    Trie() {
        nodes.reserve(MAXN);
        nodes.push_back({});
    }

    void add_string(const string& s) {
        int v = 0;
        for (size_t i = 0; i < s.length(); ++i) {
            ++nodes[v].subtree_word_count;
            int c = s[i] - 'A'; // в зависимости от алфавита
            if (nodes[v].next[c] == -1) {
                nodes.push_back({});
                nodes[v].next[c] = (int)nodes.size() - 1;
            }
            v = nodes[v].next[c];
        }
        ++nodes[v].subtree_word_count;
        nodes[v].terminal = true;
    }

    int dfs(int v, string_view s, const vector<int>& letter_by_digit, const vector<int>& digit_by_letter, ll a, ll b, string_view c) {
        if (nodes[v].subtree_word_count == 0) {
            return 0;
        }
        if (s.empty()) {
            if (nodes[v].visited && nodes[v].terminal) {
                DEBUG("visit: " << v << " a: " << a << " b: " << b << " c: " << c);
                for (int i = 0; i < 10; i++) {
                    if (letter_by_digit[i] == -1) {
                        continue;
                    }
                    DEBUG("i: " << i << " ch: " << (char)(letter_by_digit[i] + 'A'));
                }
                nodes[v].terminal = false;
                --nodes[v].subtree_word_count;
                return 1;
            }
            nodes[v].visited = true;
            return 0;
        }
        if (letter_by_digit[s[0] - '0'] != -1) {
            int removed_count = dfs(nodes[v].next[letter_by_digit[s[0] - '0']], s.substr(1), letter_by_digit, digit_by_letter, a, b, c);
            nodes[v].subtree_word_count -= removed_count;
            return removed_count;
        }
        int removed_count = 0;
        for (int i = 0; i < 26; i++) {
            int u = nodes[v].next[i];
            if (u == -1) {
                continue;
            }
            if (digit_by_letter[i] != -1) {
                continue;
            }
            removed_count += dfs(u, s.substr(1), letter_by_digit, digit_by_letter, a, b, c);
        }
        nodes[v].subtree_word_count -= removed_count;
        return removed_count;
    }

    void get_alive_words(int v, string& cur, vector<string>& result) {
        if (nodes[v].terminal && nodes[v].visited) {
            result.push_back(cur);
        }
        for (int i = 0; i < 26; i++) {
            int u = nodes[v].next[i];
            if (u == -1) {
                continue;
            }
            cur += 'A' + i;
            get_alive_words(u, cur, result);
            cur.pop_back();
        }
    }

private:
    struct Vertex {
        bool terminal;
        vector<int> next;
        int subtree_word_count;
        bool visited;

        Vertex() : terminal(false), next(26, -1), subtree_word_count(0), visited(false) {}
    };

    vector<Vertex> nodes;
};

class Solver {
public:
    void main() {
        string s;
        cin >> s;

        string t;
        cin >> t;

        Trie trie;

        int n;
        cin >> n;
        string d;
        for (int i = 0; i < n; i++) {
            cin >> d;
            trie.add_string(d);
        }

        vector<int> letters;
        for (auto ch : s) {
            letters.push_back(ch - 'A');
        }
        for (auto ch : t) {
            letters.push_back(ch - 'A');
        }
        sort(letters.begin(), letters.end());
        letters.resize(unique(letters.begin(), letters.end()) - letters.begin());

        CHECK(letters.size() <= 10);

        vector<int> digits(10);
        for (int i = 0; i < 10; i++) {
            digits[i] = i;
        }

        unordered_set<ll> visited_states;
        vector<int> digit_by_letter(26, -1);
        vector<int> letter_by_digit(10, -1);
        do {
            digit_by_letter.assign(26, -1);
            letter_by_digit.assign(10, -1);
            ll mask = 0;
            for (int i = 0; i < (int)letters.size(); i++) {
                digit_by_letter[letters[i]] = digits[i];
                letter_by_digit[digits[i]] = letters[i];
                mask = mask * 11 + (digits[i] + 1);
            }
            auto [_, emplaced] = visited_states.emplace(mask);
            if (!emplaced) {
                continue;
            }
            if (digit_by_letter[s[0] - 'A'] == 0 || digit_by_letter[t[0] - 'A'] == 0) {
                continue;
            }
            ll a = 0;
            for (auto ch : s) {
                CHECK(digit_by_letter[ch - 'A'] != -1);
                a = a * 10 + digit_by_letter[ch - 'A'];
            }
            ll b = 0;
            for (auto ch : t) {
                CHECK(digit_by_letter[ch - 'A'] != -1);
                b = b * 10 + digit_by_letter[ch - 'A'];
            }
            ll c = a + b;
            auto c_str = to_string(c);
            if (c_str == "10652" && a == 9567 && b == 1085) {
                DEBUG("check: " << c_str);
            }
            trie.dfs(0, c_str, letter_by_digit, digit_by_letter, a, b, c_str);
        } while (next_permutation(digits.begin(), digits.end()));

        string cur;
        vector<string> result;
        trie.get_alive_words(0, cur, result);
        cout << result.size() << "\n";
        for (const auto& s : result) {
            cout << s << "\n";
        }
    }
};

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
#ifdef __APPLE__
    freopen("brainteaser2.in", "r", stdin);
    // freopen("output.txt", "w", stdout);
#endif

    int t = 1;
//    cin >> t;
    for (int i = 1; i <= t; i++) {
        Solver{}.main();
    }
    return 0;
}
