#pragma comment(linker, "/STACK:2000000000")
# include <iostream>
# include <cmath>
# include <algorithm>
# include <stdio.h>
# include <cstdint>
# include <cstring>
# include <string>
# include <cstdlib>
# include <vector>
# include <bitset>
# include <map>
# include <queue>
# include <ctime>
# include <stack>
# include <set>
# include <list>
# include <random>
# include <deque>
# include <functional>
# include <iomanip>
# include <sstream>
# include <fstream>
# include <complex>
# include <numeric>
# include <immintrin.h>
# include <cassert>
# include <array>
# include <tuple>
# include <unordered_map>
# include <unordered_set>
# include <thread>

using namespace std;

using ll = long long;
using ull = unsigned long long;
using ld = long double;
using ui32 = unsigned int;
constexpr ll INFLL = 1e18;

#define CHECK_IMPL1(cond)              \
if (!(cond)) {                         \
    DEBUG("expected cond: " << #cond); \
    assert(cond);                      \
}

#define CHECK_IMPL2(cond, message)                                            \
if (!(cond)) {                                                                \
    DEBUG("expected cond: " << #cond << " failed with message: " << message); \
    assert(cond);                                                             \
}
#define CHECK_IMPL(_1, _2, NAME, ...) NAME
#define CHECK(...) CHECK_IMPL(__VA_ARGS__, CHECK_IMPL2, CHECK_IMPL1, CHECK_IMPL0)(__VA_ARGS__)

#ifdef __APPLE__
#define DEBUG(message) std::cerr << message << std::endl;
#else
#define DEBUG(message)
#endif

class SegmentTree {
public:
    SegmentTree(int n) : n_(n), t_(4 * n) {
    }

    void update(int pos) {
        update_impl(pos, 1, 1, 0, n_ - 1);
    }

    int get(int l, int r) {
        return get_impl(l, r, 1, 0, n_ - 1);
    }

private:
    void update_impl(int pos, int delta, int v, int l, int r) {
        if (l == r) {
            t_[v] += delta;
        } else {
            int m = (l + r) / 2;
            if (pos <= m) {
                update_impl(pos, delta, v * 2, l, m);
            } else {
                update_impl(pos, delta, v * 2 + 1, m + 1, r);
            }
            t_[v] = t_[v * 2] + t_[v * 2 + 1];
        }
    }

    int get_impl(int l, int r, int tv, int tl, int tr) {
        if (l > tr || r < tl) {
            return 0;
        } else if (l == tl && r == tr) {
            return t_[tv];
        } else {
            int tm = (tl + tr) / 2;
            return get_impl(l, min(tm, r), tv * 2, tl, tm) + get_impl(max(tm + 1, l), r, tv * 2 + 1, tm + 1, tr);
        }
    }

private:
    int n_;
    vector<int> t_;
};

class Solver {
public:
    pair<int, int> traverse(int v) {
        vector<pair<int, int>> results;
        results.push_back({key[v], key[v]});
        if (left[v] != -1) {
            results.push_back(traverse(left[v]));
        }
        if (right[v] != -1) {
            results.push_back(traverse(right[v]));
        }
        pair<int, int> mn = results[0];
        for (auto p : results) {
            mn.first = min(mn.first, p.first);
            mn.second = max(mn.second, p.second);
        }
        segments[v] = mn;
        return mn;
    }

    enum class EventType {
        Segment = 0,
        Query
    };

    struct Event {
        int l;
        int r;
        int index;
        EventType type;
    };

    void main() {
        int n;
        cin >> n;

        key.resize(n);
        left.resize(n);
        right.resize(n);

        for (int i = 0; i < n; i++) {
            cin >> left[i] >> right[i] >> key[i];
            --left[i];
            --right[i];
        }

        segments.resize(n);

        traverse(0);

        vector<int> points;

        int m;
        cin >> m;
        vector<pair<int, int>> queries(m);
        for (int i = 0; i < m; i++) {
            cin >> queries[i].first >> queries[i].second;
            points.push_back(queries[i].first);
            points.push_back(queries[i].second);
        }

        for (int i = 0; i < n; i++) {
            points.push_back(segments[i].first);
            points.push_back(segments[i].second);
        }

        sort(points.begin(), points.end());
        points.resize(unique(points.begin(), points.end()) - points.begin());

        vector<Event> events;

        vector<int> segment_beginnings(n);
        vector<int> segment_endings(n);
        for (int i = 0; i < n; i++) {
            segments[i].first = lower_bound(points.begin(), points.end(), segments[i].first) - points.begin();
            segments[i].second = lower_bound(points.begin(), points.end(), segments[i].second) - points.begin();

            segment_beginnings[i] = segments[i].first;
            segment_endings[i] = segments[i].second;

            events.push_back({segments[i].first, segments[i].second, i, EventType::Segment});
        }
        sort(segment_beginnings.begin(), segment_beginnings.end());
        sort(segment_endings.begin(), segment_endings.end());

        for (int i = 0; i < m; i++) {
            queries[i].first = lower_bound(points.begin(), points.end(), queries[i].first) - points.begin();
            queries[i].second = lower_bound(points.begin(), points.end(), queries[i].second) - points.begin();

            events.push_back({queries[i].first, queries[i].second, i, EventType::Query});
        }

        sort(events.begin(), events.end(), [](const auto& lhs, const auto& rhs) {
            if (lhs.l != rhs.l) {
                return lhs.l > rhs.l;
            } else {
                return lhs.type < rhs.type;
            }
        });

        inner_segment_count.resize(m);

        SegmentTree tree((int)points.size() + 1);

        for (const auto& event : events) {
            if (event.type == EventType::Segment) {
                tree.update(event.r);
            } else {
                inner_segment_count[event.index] = tree.get(event.l, event.r);
            }
        }

        for (int i = 0; i < m; i++) {
            int lefter = lower_bound(segment_endings.begin(), segment_endings.end(), queries[i].first) - segment_endings.begin();
            int righter = n - (upper_bound(segment_beginnings.begin(), segment_beginnings.end(), queries[i].second) - segment_beginnings.begin());
            DEBUG("i: " << i << " lefter: " << lefter << " righter: " << righter << " inner: " << inner_segment_count[i]);
            int crossing_segment = n - (lefter + righter + inner_segment_count[i]);
            DEBUG("crossing_segment: " << crossing_segment);
            cout << crossing_segment * 2 + 1 << "\n";
        }
    }

    vector<int> key;
    vector<int> left;
    vector<int> right;
    vector<pair<int, int>> segments;
    vector<int> inner_segment_count;
};

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
#ifdef __APPLE__
    freopen("input.txt", "r", stdin);
    // freopen("output.txt", "w", stdout);
#endif

    int t = 1;
//    cin >> t;
    for (int i = 1; i <= t; i++) {
        Solver{}.main();
    }
    return 0;
}
